# Vapi Node API Library

[![npm shield](https://img.shields.io/npm/v/@fern-api/vapi)](https://www.npmjs.com/package/@fern-api/vapi)
[![fern shield](https://img.shields.io/badge/%F0%9F%8C%BF-SDK%20generated%20by%20Fern-brightgreen)](https://github.com/fern-api/fern)

The Vapi Node.js library provides convenient access to the Vapi API from JavaScript/TypeScript.

## Documentation

API reference documentation is available [here](https://docs.vapi.ai).

## Installation

```
npm install --save @fern-api/vapi
# or
yarn add @fern-api/vapi
```

## Usage

```typescript
import { VapiClient } from @fern-api/vapi;

const vapi = new VapiClient({
  token: "YOUR_API_KEY",
});

const call = await vapi.call.createPhoneCall({
  phoneNumberId: "002-003-0004",
  customerPhoneNumber: "1-800-948-8488",
});

console.log(`Scheduled a call to Pizza Hut! The agent id is ${call.agentId}`);
```

## Handling errors

When the API returns a non-success status code (4xx or 5xx response), 
a subclass of [VapiError](./src/errors/VapiError.ts) will be thrown:

```ts
try {
  await vapi.call.createPhoneCall(...);
} catch (err) {
  if (err instanceof VapiError) {
    console.log(err.statusCode);
    console.log(err.message);
    console.log(err.body);
  }
}
```

## Retries

409 Conflict, 429 Rate Limit, and >=500 Internal errors will all be retried twice with exponential bakcoff.
You can use the maxRetries option to configure this behavior:

```typescript
const sites = await vapi.call.get("call-id", {
    maxRetries: 0, // disable retries
});
```

## Timeouts

By default, the SDK has a timeout of 60s. You can use the `timeoutInSeconds` option to configure
this behavior

```typescript
const sites = await vapi.call.get("call-id", {
    timeoutInSeconds: 10, // timeout after 10 seconds
});
```

## Beta status

This SDK is in beta, and there may be breaking changes between versions without a major version update. 
Therefore, we recommend pinning the package version to a specific version in your package.json file.
This way, you can install the same version each time without breaking changes unless you are intentionally looking for the latest version.

## Contributing

While we value open-source contributions to this SDK, this library is generated programmatically. 
Additions made directly to this library would have to be moved over to our generation code, otherwise 
they would be overwritten upon the next generated release. Feel free to open a PR as a proof of concept, 
but know that we will not be able to merge it as-is.

We suggest [opening an issue](https://github.com/fern-vapi/vapi-node/issues) first to discuss with us!

On the other hand, contributions to the README are always very welcome!
